@@ -55,6 +55,10 @@ class dbd_bot():
 		self._codes={}
 		self._cooldown={}
 		self._db=_variables()
+		try:
+			self._help=info["help"]=="true"
+		except:
+			self._help=True
 		try:
 			self._db.path=name.rstrip(os.path.basename(info["path"]))
 			self._db.load()
@@ -65,6 +69,7 @@ class dbd_bot():
 		except:
 			self._style="[]"
 		self._client=commands.Bot(command_prefix=self._prefix, intents=discord.Intents.all())
+		self._client.remove_command(help)
 
 	def command(self, info):
 		self._codes["command:"+info["name"]]={}
@@ -106,12 +111,22 @@ class dbd_bot():
 
 def _start(client, bot):
 	import time
+	import re
 	import asyncio
 	import discord
 	import random
 	from discord.ext import commands
 	startTime=time.time()
 	def replaces(line, message, guild, content):
+		content2=content
+		try:
+			for m in message.mentions:
+				content2=content2.replace(str(m.mention).replace("!",""),"")
+			if content2[0]==" ":
+				content2=content2[1:]
+		except:
+			pass
+		content2=re.sub("\s\s+", " ", content2)
 		line=line.replace("$uptime",str(int(time.time() - startTime)))
 		line=line.replace("$ping",str(round(client.latency*1000)))
 		try:
@@ -130,6 +145,12 @@ def _start(client, bot):
 				line=line.replace("$message"+bot._style[0]+line.split("$message"+bot._style[0])[1].split(bot._style[1])[0]+bot._style[1], content.split(" ")[int(line.split("$message"+bot._style[0])[1].split(bot._style[1])[0])-1])
 			except:
 				line=line.replace("$message"+bot._style[0]+line.split("$message"+bot._style[0])[1].split(bot._style[1])[0]+bot._style[1],"")
+		while "$noMentionMessage"+bot._style[0] in line:
+			try:
+				line=line.replace("$noMentionMessage"+bot._style[0]+line.split("$noMentionMessage"+bot._style[0])[1].split(bot._style[1])[0]+bot._style[1], content2.split(" ")[int(line.split("$noMentionMessage"+bot._style[0])[1].split(bot._style[1])[0])-1])
+			except:
+				line=line.replace("$noMentionMessage"+bot._style[0]+line.split("$noMentionMessage"+bot._style[0])[1].split(bot._style[1])[0]+bot._style[1],"")
+		line=line.replace("$noMentionMessage", content2)
 		line=line.replace("$message", content)
 		while "$mentioned"+bot._style[0] in line:
 			try:
@@ -589,7 +610,7 @@ def _start(client, bot):
 					bot._db.save()
 				except Exception as e:
 					print(f"Ошибка в функции {line}")
-					raise e
+					print(e)
 			else:
 				go-=1
 	
@@ -629,11 +650,18 @@ def _start(client, bot):
 			try:
 				await use(message, "message_delete", "")
 			except Exception as e:
-				pass
+				raise e
 
 	@client.event
 	async def on_message(message):
 		if message.author.id!=client.user.id and not message.author.bot:
+			if str(message.content).startswith(bot._client.user.mention):
+				if bot._help:
+					cmds=""
+					for c in bot._codes:
+						if c.startswith("command:"):
+							cmds+=bot._codes[c]["name"]+"\n"
+					await message.channel.send(embed=discord.Embed(title="Комманды("+str(len(cmds.split("\n"))-1)+")",description=f"```py\n{cmds}\n```"))
 			for cmd in bot._codes:
 				if cmd.startswith("command:"):
 					if "$case" in bot._codes[cmd]["code"]:
